arthub_login_widgets
=========
[![Build Status](https://badge.orange-ci.woa.com/lightbox/internal/arthub_login_widgets.svg)](http://orange-ci.oa.com/build/log/latest?slug=lightbox/internal/arthub_login_widgets)
![](https://metrics.woa.com/git/lightbox/internal/arthub_login_widgets/-/latest/ci/status/push)
![](https://metrics.woa.com/git/lightbox/internal/arthub_login_widgets/-/latest/ci/pipeline-as-code)
![](https://metrics.woa.com/git/lightbox/internal/arthub_login_widgets/-/latest/ci/clone-cost)
![](https://metrics.woa.com/git/lightbox/internal/arthub_login_widgets/-/latest/code/repo-config)
![](https://metrics.woa.com/git/lightbox/internal/arthub_login_widgets/-/latest/testing/unit/coverage)

A Qt Widget for login ArtHub.
